@@ -1,5 +1,5 @@
 package Stepford::Role::Step::FileGenerator::Atomic;
-$Stepford::Role::Step::FileGenerator::Atomic::VERSION = '0.003002';
+$Stepford::Role::Step::FileGenerator::Atomic::VERSION = '0.003003';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -59,7 +59,7 @@ around run => sub {
 
     # The step's run() method may decide to simply not do anything if the
     # post-commit file already exists, and that's ok.
-    return if -f $post_commit;
+    return if -f $post_commit && ! -f $pre_commit;
 
     croak 'The '
         . ( ref $self )
@@ -68,6 +68,7 @@ around run => sub {
         . " $pre_commit"
         unless -f $pre_commit;
 
+    $self->logger()->debug("Renaming $pre_commit to $post_commit");
     rename( $pre_commit, $post_commit )
         or croak "Failed renaming $pre_commit -> $post_commit: $!";
 };
@@ -86,7 +87,7 @@ Stepford::Role::Step::FileGenerator::Atomic - A role for steps that generate a f
 
 =head1 VERSION
 
-version 0.003002
+version 0.003003
 
 =head1 DESCRIPTION
 
